package com.platomix.intchannel.config;

import java.io.Serializable;

/**
 * 响应信息主体
 *
 * @author ruoyi
 */
public class R<T> implements Serializable {
	
	private static final long serialVersionUID = 1L;

	/** 成功 */
	public static final int SUCCESS = 200;

	/** 失败 */
	public static final int FAILURE = 500;

	private int code;

	private String msg;

	private T data;
	
	private String ext;

	public static <T> R<T> ok() {
		return restResult(null, SUCCESS, null);
	}

	public static <T> R<T> ok(T data) {
		return restResult(data, SUCCESS, null);
	}

	public static <T> R<T> ok(T data, String msg) {
		return restResult(data, SUCCESS, msg);
	}
	
	public static <T> R<T> ok(T data, String ext, String msg) {
		return restResult(data, SUCCESS, ext, msg);
	}

	public static <T> R<T> fail() {
		return restResult(null, FAILURE, null);
	}

	public static <T> R<T> fail(String msg) {
		return restResult(null, FAILURE, msg);
	}
	
	public static <T> R<T> fail(String msg, String ext) {
		return restResult(null, FAILURE, ext, msg);
	}

	public static <T> R<T> fail(T data) {
		return restResult(data, FAILURE, null);
	}

	public static <T> R<T> fail(T data, String msg) {
		return restResult(data, FAILURE, msg);
	}

	public static <T> R<T> fail(int code, String msg) {
		return restResult(null, code, msg);
	}
	
	public static <T> R<T> fail(int code, String ext, String msg) {
		return restResult(null, code, ext, msg);
	}
	
	public static <T> R<T> status(boolean ret){
		return restResult(null, ret ? SUCCESS : FAILURE, ret ? "操作成功" : "操作失败");
	}

	private static <T> R<T> restResult(T data, int code, String msg) {
		R<T> apiResult = new R<>();
		apiResult.setCode(code);
		apiResult.setData(data);
		apiResult.setMsg(msg);
		return apiResult;
	}
	
	private static <T> R<T> restResult(T data, int code, String ext, String msg) {
		R<T> apiResult = restResult(data, code, msg);
		apiResult.setExt(ext);
		return apiResult;
	}
	
	public int getCode() {
		return code;
	}

	public void setCode(int code) {
		this.code = code;
	}

	public String getMsg() {
		return msg;
	}

	public void setMsg(String msg) {
		this.msg = msg;
	}

	public T getData() {
		return data;
	}

	public void setData(T data) {
		this.data = data;
	}

	/**
	 * @return the ext
	 */
	public String getExt() {
		return ext;
	}

	/**
	 * @param ext the ext to set
	 */
	public void setExt(String ext) {
		this.ext = ext;
	}
	
}
