/**
 * 
 */
package com.platomix.intchannel.config;

import com.github.xiaoymin.knife4j.spring.extension.OpenApiExtensionResolver;
import com.platomix.intchannel.utils.TokenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.ParameterBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.schema.ModelRef;
import springfox.documentation.service.*;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spi.service.contexts.SecurityContext;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2WebMvc;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

/**
 * @author wookvn
 *
 */
@Configuration
@EnableSwagger2WebMvc
public class SwaggerConfig {
	
	@Autowired
	private OpenApiExtensionResolver openApiExtensionResolver;

	@Bean
	public Docket createRestApi() {
		return new Docket(DocumentationType.SWAGGER_2)
				.apiInfo(apiInfo())
				.select()
				//扫描哪些包需要配置接口说明(一般controller)
				.apis(RequestHandlerSelectors.basePackage("com.platomix.intchannel.controller"))
				.paths(PathSelectors.any())
				.build().securityContexts(securityContexts()).securitySchemes(securitySchemas())
				.globalOperationParameters(globalParameter())
				.extensions(openApiExtensionResolver.buildExtensions(null));
	}
	
	private List<Parameter> globalParameter(){
		return Arrays.asList(new ParameterBuilder()
	            .name(TokenUtil.PLATOMIX_TOKEN_HEADER)
	            .description("platomixAuth")
	            .modelRef(new ModelRef("string"))
	            .parameterType("header")
	            .required(false)
	            .build());
	}
	
	private List<SecurityContext> securityContexts() {
		return Collections.singletonList(SecurityContext.builder()
			.securityReferences(defaultAuth())
			.forPaths(PathSelectors.regex("^.*$"))
			.build());
	}

	List<SecurityReference> defaultAuth() {
		AuthorizationScope authorizationScope = new AuthorizationScope("global", "accessEverywhere");
		AuthorizationScope[] authorizationScopes = new AuthorizationScope[1];
		authorizationScopes[0] = authorizationScope;
		return Collections.singletonList(new SecurityReference(TokenUtil.PLATOMIX_TOKEN_HEADER, authorizationScopes));
	}
	
	private List<SecurityScheme> securitySchemas() {
		return Collections.singletonList(new ApiKey("platomixAuth", TokenUtil.PLATOMIX_TOKEN_HEADER, "header"));
	}

	private ApiInfo apiInfo() {
		return new ApiInfoBuilder()
				.title("接口文档")
				.version("v1.0.0")
				.description("基于SpringBoot-2.2.13.RELEASE开发，使用 swagger2 构建 Resultful API接口。")
				.license("Apache License 2.0")
				.licenseUrl("https://choosealicense.com/licenses/apache-2.0/")
				.build();
	}
}
