/**
 * 
 */
package com.platomix.intchannel.controller;

import java.util.Date;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.platomix.intchannel.config.R;
import com.platomix.intchannel.model.ChannelUser;
import com.platomix.intchannel.service.ChannelUserService;
import com.platomix.intchannel.utils.Convert;
import com.platomix.intchannel.utils.StringKit;
import com.platomix.intchannel.utils.TokenUtil;

import cn.hutool.crypto.digest.MD5;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * @author wookvn
 *
 */
@RestController
@RequestMapping("/finance/channelUser")
@Api(value = "用户管理", tags = "用户管理接口")
public class ChannelUserController {

	@Autowired
	private ChannelUserService channelUserService;
	
	/**
	 * 
	 * @param channelId
	 * @return
	 */
	@GetMapping("/list")
	@ApiOperation("用户列表")
	public R<IPage<ChannelUser>> list(String channelId, Integer pageNum, Integer limit){
		LambdaQueryWrapper<ChannelUser> queryWrapper = Wrappers.lambdaQuery(ChannelUser.class).orderByDesc(ChannelUser::getUserId);
		if(StringKit.isNotEmpty(channelId)) {
			queryWrapper.eq(ChannelUser::getChannelId, channelId);
		}
		IPage<ChannelUser> page = new Page<>(Convert.toInt(pageNum, 1), Convert.toInt(limit, 10));
		IPage<ChannelUser> resultPage = channelUserService.page(page, queryWrapper);
		if(resultPage != null && resultPage.getRecords() != null) {
			resultPage.getRecords().forEach(f -> f.setPassWord("********"));
		}
		return R.ok(resultPage);
	}
	
	/**
	 * 
	 * @param channelUser
	 * @return
	 */
	@PostMapping("/saveOrUpdate")
	@ApiOperation("新增或更新")
	public R<String> doSaveOrUpdate(@RequestBody ChannelUser channelUser){
		if(!TokenUtil.isSuperMan()) {
			return R.fail("您没有权限操作");
		}
		if(StringKit.isNotEmpty(channelUser.getPassWord())) {
			channelUser.setPassWord(MD5.create().digestHex(channelUser.getPassWord()));
		}
		channelUser.setDisableStatus(0);
		//channelUser.setSuperMan(0);
		channelUser.setCreateTime(new Date());
		return R.status(channelUserService.saveOrUpdate(channelUser));
	}
	
	/**
	 * 
	 * @param userId
	 * @return
	 */
	@PostMapping("/remove")
	@ApiOperation("删除")
	public R<String> remove(Long userId){
		if(!TokenUtil.isSuperMan()) {
			return R.fail("您没有权限操作");
		}
		return R.status(channelUserService.removeById(userId));
	}
	
	/**
	 * 
	 * @param userId
	 * @param status
	 * @return
	 */
	@PostMapping("/switchStatus")
	@ApiOperation("更新账号状态")
	public R<String> switchStatus(Long userId, Integer disableStatus){
		ChannelUser entity = new ChannelUser();
		entity.setUserId(userId);
		entity.setDisableStatus(disableStatus);
		return R.status(channelUserService.updateById(entity));
	}
	
	/**
	 * 
	 * @return
	 */
	@PostMapping("/uptPass")
	@ApiOperation("更新账号密码【注：给当前登录用户使用】")
	public R<String> doUpdatePass(@RequestParam String oldPass, @RequestParam String newPass){
		if(newPass.equals(oldPass)) {
			return R.fail("新旧密码不能相同");
		}
		Long userId = TokenUtil.getUserId();
		ChannelUser channelUser = channelUserService.getById(userId);
		if(channelUser == null) {
			return R.fail("该账号不存在");
		}
		if(!MD5.create().digestHex(oldPass).equals(channelUser.getPassWord())) {
			return R.fail("旧密码错误");
		}
		ChannelUser entity = new ChannelUser();
		entity.setUserId(userId);
		entity.setPassWord(MD5.create().digestHex(newPass));
		return R.status(channelUserService.updateById(entity));
	}
}
