/**
 * 
 */
package com.platomix.intchannel.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.platomix.intchannel.config.R;
import com.platomix.intchannel.enums.AuditStatusEnum;
import com.platomix.intchannel.model.*;
import com.platomix.intchannel.service.*;
import com.platomix.intchannel.utils.Convert;
import com.platomix.intchannel.utils.TokenUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.io.FileUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.util.Date;
import java.util.List;
import java.util.UUID;
import java.util.stream.Collectors;

/**
 * @author wookvn
 *
 */
@Slf4j
@RestController
@RequestMapping("/finance/billAudit")
@Api(value = "结算单审核", tags = "结算单审核接口")
public class FinanceBillAuditController {

	@Autowired
	private FinanceBillAuditService financeBillAuditService;
	
	@Autowired
	private DateRangeAccountService dateRangeAccountService;
	
	@Autowired
	private ChannelSpidService channelSpidService;
	
	@Autowired
	private PdfExportService pdfExportService;

	@Autowired
	private PdfExportWXService pdfExportWXService;

	@Autowired
	private IntBackFileService intBackFileService;

	@Autowired
	private DealUserAccountsService dealUserAccountsService;

	@Autowired
	private IntOdrangeAccountSubViewService intOdrangeAccountSubViewService;
	
	/**
	 * @return
	 */
	@GetMapping("/list")
	@ApiOperation(value = "分页查询")
	public R<IPage<FinanceBillAudit>> list(Integer pageNum, Integer limit,String queryDate){
		QueryWrapper<FinanceBillAudit> queryWrapper = Wrappers.<FinanceBillAudit>query();

		String dealUserId = TokenUtil.getDealUserId();
		QueryWrapper<DealUserAccounts> dealQueryWrapper = new QueryWrapper<DealUserAccounts>();
		dealQueryWrapper.select("DEAL_ACCOUNT_ID").isNotNull("DEAL_ACCOUNT_ID");
		dealQueryWrapper.eq("DEAL_USERID",dealUserId);
		List<DealUserAccounts> dealList = dealUserAccountsService.list(dealQueryWrapper);
		List<String> collect = dealList.stream().map(DealUserAccounts::getDealAccountId).collect(Collectors.toList());
		if(!StringUtils.isEmpty(queryDate)) {
			queryWrapper.eq("ioa.THEMONTH", queryDate.replace("-", ""));
		}
		queryWrapper.in("ioa.DEAL_ACCOUNT_ID", collect)
		.in("fba.AUDITSTATUS", AuditStatusEnum.fin_reject.getValue(), AuditStatusEnum.fin_upload.getValue(), AuditStatusEnum.wait_upload.getValue());
		Page<FinanceBillAudit> page = new Page<>(Convert.toInt(pageNum, 1), Convert.toInt(limit, 10));
		//没有查询条件
		List<Long> aidList = financeBillAuditService.customAidList(page, queryWrapper);
		IPage<FinanceBillAudit> customPage = new Page<FinanceBillAudit>(Convert.toInt(pageNum, 1), Convert.toInt(limit, 10));
		if(aidList != null && !aidList.isEmpty()) {
			customPage.setTotal(financeBillAuditService.customCount(queryWrapper));
			List<FinanceBillAudit> custom = financeBillAuditService.customList(Wrappers.<FinanceBillAudit>query().in("fba.AID", aidList));
			for (FinanceBillAudit financeBillAudit : custom) {
				DateRangeAccount dateRangeAccount = financeBillAudit.getDateRangeAccount();
				if(!StringUtils.isEmpty(dateRangeAccount.getChannelName()) && dateRangeAccount.getChannelName().equals("微信支付")){
					List<IntOdrangeAccountSubView> subList = intOdrangeAccountSubViewService.list(new LambdaQueryWrapper<IntOdrangeAccountSubView>()
							.eq(IntOdrangeAccountSubView::getSid, dateRangeAccount.getSid())
					);
					financeBillAudit.setSubList(subList);
				}

				//回传文件列表
				List<IntBackFile> backFiles = intBackFileService.list(new LambdaQueryWrapper<IntBackFile>()
						.eq(IntBackFile::getAid, financeBillAudit.getAid())
						.eq(IntBackFile::getIsDelete, 0)
						.orderByDesc(IntBackFile::getUploadTime)
				);
				if(backFiles != null && backFiles.size() > 0){
					financeBillAudit.setFid(backFiles.get(0).getFid().toString());
					financeBillAudit.setUploadFileName(backFiles.get(0).getUploadFileName());
					financeBillAudit.setUploadFileUri(backFiles.get(0).getUploadFileUri());
					financeBillAudit.setUploadTime(backFiles.get(0).getUploadTime());
				}
			}
			customPage.setRecords(custom);
			if(customPage != null && customPage.getRecords() != null) {
				customPage.getRecords().forEach(f -> {
					f.setUserNames(String.join("、", f.getUserList().stream().map(FinanceBillAuditUser::getUserName).collect(Collectors.toList())));
				});
			}
		}
		return R.ok(customPage);
	}
	
	
	/**
	 * 驳回
	 * @param aid
	 * @param rejectReason
	 * @return
	 */
	@PostMapping("/reject")
	@ApiOperation(value = "驳回接口")
	public R<String> reject(String aid, String rejectReason){
		FinanceBillAudit entity = new FinanceBillAudit();
		entity.setAid(Long.valueOf(aid));
		entity.setRejectReason(rejectReason);
		entity.setAuditStatus(AuditStatusEnum.fin_reject.getValue());
		entity.setRejectTime(new Date());
		return R.status(financeBillAuditService.updateById(entity));
	}
	
	/**
	 * 
	 * @param aid
	 * @return
	 */
	@PostMapping("/confirm")
	@ApiOperation(value = "确认接收接口")
	public R<String> cancel(String aid){
		FinanceBillAudit entity = new FinanceBillAudit();
		entity.setAid(Long.valueOf(aid));
		entity.setAuditStatus(AuditStatusEnum.wait_upload.getValue());
		return R.status(financeBillAuditService.updateById(entity));
	}
	
	/**
	 * 回传接口
	 * @param aid
	 * @return
	 */
	@PostMapping("/upload")
	@ApiOperation(value = "回传接口")
	public R<String> upload(String aid, String uploadFileName, String uploadFileUri){
		FinanceBillAudit entity = new FinanceBillAudit();
		entity.setAid(Long.valueOf(aid));
		entity.setUploadFileName(uploadFileName);
		entity.setUploadFileUri(uploadFileUri);
		entity.setUploadTime(new Date());
		entity.setAuditStatus(AuditStatusEnum.fin_upload.getValue());
		return R.status(financeBillAuditService.updateById(entity));
	}


	/**
	 * 回传接口
	 * @param aid
	 * @return
	 */
	@PostMapping("/backFile")
	@ApiOperation(value = "二次回传接口")
	public R backFile(String aid, String uploadFileName, String uploadFileUri){
		IntBackFile entity = new IntBackFile();
		entity.setAid(Long.valueOf(aid));
		entity.setUploadFileName(uploadFileName);
		entity.setUploadFileUri(uploadFileUri);
		entity.setUploadTime(new Date());
		entity.setIsDelete(0);
		boolean sa = intBackFileService.save(entity);
		if(sa){
			FinanceBillAudit audit = financeBillAuditService.getById(aid);
			if(audit != null){
				audit.setAuditStatus(AuditStatusEnum.fin_upload.getValue());
				return R.status(financeBillAuditService.updateById(audit));
			}
			return R.fail("结算单不存在");
		}
		return R.fail("回传文件失败");
	}



	/**
	 * 删除回传文件
	 * @param aid
	 * @param fid
	 * @return
	 */
	@PostMapping("/removeFile")
	@ApiOperation(value = "删除回传文件")
	public R removeFile(String aid, Long fid){
		IntBackFile backFile = intBackFileService.getById(fid);
		if(backFile == null){
			return R.fail("文件不存在");
		}
		backFile.setIsDelete(1);
		boolean edit = intBackFileService.updateById(backFile);
		if(edit){
			FinanceBillAudit audit = financeBillAuditService.getById(aid);
			if(audit != null){
				audit.setAuditStatus(AuditStatusEnum.wait_upload.getValue());
				return R.status(financeBillAuditService.updateById(audit));
			}
		}
		return R.fail("回传文件失败");
	}



	/**
	 * 下载结算表PDF数据
	 * @param sid
	 * @param downloadType
	 * @param response
	 * @throws Exception
	 */
	@GetMapping("/downloadPdf")
	@ApiOperation(value = "下载结算表PDF数据")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "downloadType", value = "下载类型(one-第一次结算表PDF/two-第二次结算表PDF)", dataType = "string", required = true),
		@ApiImplicitParam(name = "sid", value = "结算单唯一ID", dataType = "string", required = true)
	})
	public void downloadPdf(@RequestParam Integer reqType,@RequestParam Long sid, @RequestParam String downloadType, HttpServletResponse response) throws Exception {
		LambdaQueryWrapper<DateRangeAccount> queryWrapper = Wrappers.lambdaQuery(DateRangeAccount.class).eq(DateRangeAccount::getSid, sid);
		DateRangeAccount dateRangeAccount = dateRangeAccountService.getOne(queryWrapper);
		if(dateRangeAccount != null) {
			// Http 1.0 header
	        response.setDateHeader("Expires", 0);
	        response.addHeader("Pragma", "no-cache");
	        // Http 1.1 header
	        response.setHeader("Cache-Control", "no-cache");
	        String encodedfileName = new String((("one".equalsIgnoreCase(downloadType) ? "第一次" : "第二次") + "结算确认单").getBytes("GBK"), "ISO8859-1");
	        response.setHeader("Content-Disposition", "attachment; filename=\"" + encodedfileName + ".pdf\"");
			response.setContentType("application/vnd.ms-pdf");
			
			ByteArrayOutputStream baos = new ByteArrayOutputStream();
			if(reqType == null){
				reqType = 2;
			}
			//社会渠道结算
			if(reqType == 1){
				if(dateRangeAccount.getChannelName().equals("微信支付")){
					if("one".equals(downloadType)) {
						pdfExportWXService.createOnePdf(dateRangeAccount, baos);
					}else {
						pdfExportWXService.createTwoPdf(dateRangeAccount, baos);
					}
				}else if("one".equals(downloadType)) {
					pdfExportService.createOnePdf(dateRangeAccount, baos);
				}else {
					pdfExportService.createTwoPdf(dateRangeAccount, baos);
				}
			}
			//互联网1 去掉总扣罚金额字段
			if(reqType == 2){
				if(dateRangeAccount.getChannelName().equals("微信支付")){
					if("one".equals(downloadType)) {
						pdfExportWXService.createOnePdf(dateRangeAccount, baos);
					}else {
						pdfExportWXService.createTwoPdf(dateRangeAccount, baos);
					}
				}else if("one".equals(downloadType)) {
					pdfExportService.createH1OnePdf(dateRangeAccount, baos);
				}else {
					pdfExportService.createH1TwoPdf(dateRangeAccount, baos);
				}
			}
			response.getOutputStream().write(baos.toByteArray());
			response.getOutputStream().flush();
		}
	}
	
	@Value("${file.uploadPath}")
	private String uploadPath;

	/**
	 * 
	 * @param file
	 * @return
	 */
	@PostMapping("/uploadFile")
	@ApiOperation(value = "文件上传接口", notes = "文件上传接口")
	public R<JSONObject> uploadFile(MultipartFile file) {
		if (null == file) {
			return R.fail("文件不能为空");
		}
		//图片上传
		String oFileName = file.getOriginalFilename();
		String fileSuffix = oFileName.substring(oFileName.lastIndexOf("."));

//		if (!".jpg".equalsIgnoreCase(fileSuffix) &&
//			!".pdf".equalsIgnoreCase(fileSuffix) &&
//			!".png".equalsIgnoreCase(fileSuffix)
//		) {
//			return R.fail("只能上传jpg/pdf/png类型的文件");
//		}
		String tempFileName = UUID.randomUUID().toString() + fileSuffix;
		File f = new File(uploadPath + tempFileName);
		try {
			FileUtils.copyInputStreamToFile(file.getInputStream(), f);
//			file.transferTo(f);
			JSONObject jsonObject = new JSONObject();
			jsonObject.put("url", "uploads/intchannel/" + tempFileName);
			return R.ok(jsonObject);
		} catch (Exception e) {
			log.error(e.getMessage());
			return R.fail("上传文件失败");
		}
	}
	
}
