package com.platomix.intchannel.controller;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.itextpdf.text.*;
import com.itextpdf.text.pdf.BaseFont;
import com.itextpdf.text.pdf.PdfPCell;
import com.itextpdf.text.pdf.PdfPTable;
import com.itextpdf.text.pdf.PdfWriter;
import com.platomix.intchannel.config.R;
import com.platomix.intchannel.enums.AuditStatusEnum;
import com.platomix.intchannel.enums.PartnerInformationEnum;
import com.platomix.intchannel.model.*;
import com.platomix.intchannel.service.*;
import com.platomix.intchannel.utils.ChineseYuanUtil;
import com.platomix.intchannel.utils.Convert;
import com.platomix.intchannel.utils.TokenUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ClassPathResource;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.ByteArrayOutputStream;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 * 结算单审核表 前端控制器
 * </p>
 *
 * @author zbc
 * @since 2022-04-07
 */
@RestController
@RequestMapping("finance/yksytBillAudit")
@Api(value = "渠道商推送单审核", tags = "渠道商推送单审核")
@Slf4j
public class YksytFinanceBillAuditController {


	@Autowired
	private YksytFinanceBillAuditService yksytFinanceBillAuditService;

	@Autowired
	private YksytAccountService yksytAccountService;

	@Autowired
	private YksytChannelsService yksytChannelsService;

	@Autowired
	private ChannelSpidViewService channelSpidViewService;

	@Autowired
	private YksytBackFileService yksytBackFileService;

	@Autowired
	private FinVippoolMonthDetailService finVippoolMonthDetailService;

	@Autowired
	private DealUserAccountsService dealUserAccountsService;

	@Autowired
	private YksytAccountViewService yksytAccountViewService;

	/**
	 * @return
	 */
	@GetMapping("/list")
	@ApiOperation(value = "分页查询")
	public R<IPage<YksytFinanceBillAudit>> list(Integer pageNum, Integer limit){
		QueryWrapper<YksytFinanceBillAudit> queryWrapper = Wrappers.<YksytFinanceBillAudit>query();
		String dealUserId = TokenUtil.getDealUserId();
		QueryWrapper<DealUserAccounts> dealQueryWrapper = new QueryWrapper<DealUserAccounts>();
		dealQueryWrapper.select("DEAL_ACCOUNT_ID").isNotNull("DEAL_ACCOUNT_ID");
		dealQueryWrapper.eq("DEAL_USERID",dealUserId);
		List<DealUserAccounts> dealList = dealUserAccountsService.list(dealQueryWrapper);
		List<String> collect = dealList.stream().map(DealUserAccounts::getDealAccountId).collect(Collectors.toList());


		queryWrapper.in("ya.DEAL_ACCOUNT_ID", collect)
				.in("yfba.AUDITSTATUS", AuditStatusEnum.fin_reject.getValue(), AuditStatusEnum.fin_upload.getValue(), AuditStatusEnum.wait_upload.getValue());

		Page<YksytFinanceBillAudit> page = new Page<>(Convert.toInt(pageNum, 1), Convert.toInt(limit, 10));
		//没有查询条件
		List<Long> aidList = yksytFinanceBillAuditService.customAidList(page, queryWrapper);
		IPage<YksytFinanceBillAudit> customPage = new Page<YksytFinanceBillAudit>(Convert.toInt(pageNum, 1), Convert.toInt(limit, 10));
		if(aidList != null && !aidList.isEmpty()) {
			customPage.setTotal(yksytFinanceBillAuditService.customCount(queryWrapper));

			List<YksytFinanceBillAudit> custom = yksytFinanceBillAuditService.customList(Wrappers.<YksytFinanceBillAudit>query().in("yfba.AID", aidList));
			for (YksytFinanceBillAudit yksytFinanceBillAudit : custom) {
				YksytAccountView yksytAccount = yksytFinanceBillAudit.getYksytAccount();
				String convert = "";
				if(new BigDecimal(yksytAccount.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP).compareTo(BigDecimal.ZERO) < 0){
					//负数金额
					convert = "负数"+ChineseYuanUtil.convert(new BigDecimal(yksytAccount.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP).multiply(new BigDecimal(-1)).toString());
				}else {
					convert = ChineseYuanUtil.convert(new BigDecimal(yksytAccount.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP).toString());
				}
				//String convert = ChineseYuanUtil.convert(new BigDecimal(yksytAccount.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP).toString());
				yksytAccount.setConvert(convert);

				//回传文件列表
				List<YksytBackFile> backFiles = yksytBackFileService.list(new LambdaQueryWrapper<YksytBackFile>()
						.eq(YksytBackFile::getAid, yksytFinanceBillAudit.getAid())
						.eq(YksytBackFile::getIsDelete, 0)
						.orderByDesc(YksytBackFile::getUploadTime)
				);
				if(backFiles != null && backFiles.size() > 0){
					yksytFinanceBillAudit.setFid(backFiles.get(0).getFid().toString());
					yksytFinanceBillAudit.setUploadFileName(backFiles.get(0).getUploadFileName());
					yksytFinanceBillAudit.setUploadFileUri(backFiles.get(0).getUploadFileUri());
					yksytFinanceBillAudit.setUploadTime(backFiles.get(0).getUploadTime());
				}

				//会员权益列表
				List<FinVippoolMonthDetail> list = null;
				if(yksytAccount != null && StringUtils.isNotBlank(yksytAccount.getChannelName())){
					list = finVippoolMonthDetailService.list(new LambdaQueryWrapper<FinVippoolMonthDetail>()
							.eq(FinVippoolMonthDetail::getCpShortname,yksytAccount.getChannelName())
							.eq(FinVippoolMonthDetail::getThemonth,yksytAccount.getThemonth())
					);
				}

				PartnerInformationEnum[] values = PartnerInformationEnum.values();
				for (PartnerInformationEnum value : values) {
					if(value.getPartnerName().equals(yksytAccount.getCompany())){
						yksytAccount.setBankName(value.getBankName());
						yksytAccount.setBankCode(value.getBankCode());
					}
				}

				if(list != null && list.size() > 0){
					yksytAccount.setVipList(list);
				}
			}
			customPage.setRecords(custom);
			log.info("custom = {}",custom);
			if(customPage != null && customPage.getRecords() != null) {
				customPage.getRecords().forEach(f -> {
					f.setUserNames(String.join("、", f.getUserList().stream().map(YksytFinanceBillAuditUser::getUserName).collect(Collectors.toList())));
				});
			}
		}
		log.info("customPage = {}",customPage);
		return R.ok(customPage);
	}



	/**
	 * 驳回
	 * @param aid
	 * @param rejectReason
	 * @return
	 */
	@PostMapping("/reject")
	@ApiOperation(value = "驳回接口")
	public R<String> reject(String aid, String rejectReason){
		YksytFinanceBillAudit entity = new YksytFinanceBillAudit();
		entity.setAid(Long.valueOf(aid));
		entity.setRejectReason(rejectReason);
		entity.setAuditStatus(AuditStatusEnum.fin_reject.getValue());
		entity.setRejectTime(new Date());
		return R.status(yksytFinanceBillAuditService.updateById(entity));
	}

	/**
	 *
	 * @param aid
	 * @return
	 */
	@PostMapping("/confirm")
	@ApiOperation(value = "确认接收接口")
	public R<String> cancel(String aid){
		YksytFinanceBillAudit entity = new YksytFinanceBillAudit();
		entity.setAid(Long.valueOf(aid));
		entity.setAuditStatus(AuditStatusEnum.wait_upload.getValue());
		return R.status(yksytFinanceBillAuditService.updateById(entity));
	}

	@PostMapping("/upload")
	@ApiOperation(value = "回传接口")
	public R<String> upload(String aid, String uploadFileName, String uploadFileUri){
		YksytFinanceBillAudit entity = new YksytFinanceBillAudit();
		entity.setAid(Long.valueOf(aid));
		entity.setUploadFileName(uploadFileName);
		entity.setUploadFileUri(uploadFileUri);
		entity.setUploadTime(new Date());
		entity.setAuditStatus(AuditStatusEnum.fin_upload.getValue());
		return R.status(yksytFinanceBillAuditService.updateById(entity));
	}


	/**
	 * 回传接口
	 * @param aid
	 * @return
	 */
	@PostMapping("/backFile")
	@ApiOperation(value = "二次回传接口")
	public R backFile(String aid, String uploadFileName, String uploadFileUri){
		YksytBackFile entity = new YksytBackFile();
		entity.setAid(Long.valueOf(aid));
		entity.setUploadFileName(uploadFileName);
		entity.setUploadFileUri(uploadFileUri);
		entity.setUploadTime(new Date());
		entity.setIsDelete(0);
		boolean sa = yksytBackFileService.save(entity);
		if(sa){
			YksytFinanceBillAudit audit = yksytFinanceBillAuditService.getById(aid);
			if(audit != null){
				audit.setAuditStatus(AuditStatusEnum.fin_upload.getValue());
				return R.status(yksytFinanceBillAuditService.updateById(audit));
			}
			return R.fail("结算单不存在");
		}
		return R.fail("回传文件失败");
	}


	/**
	 * 删除回传文件
	 * @param aid
	 * @param fid
	 * @return
	 */
	@PostMapping("/removeFile")
	@ApiOperation(value = "删除回传文件")
	public R removeFile(String aid, Long fid){
		YksytBackFile backFile = yksytBackFileService.getById(fid);
		if(backFile == null){
			return R.fail("文件不存在");
		}
		backFile.setIsDelete(1);
		boolean edit = yksytBackFileService.updateById(backFile);
		if(edit){
			YksytFinanceBillAudit audit = yksytFinanceBillAuditService.getById(aid);
			if(audit != null){
				audit.setAuditStatus(AuditStatusEnum.wait_upload.getValue());
				return R.status(yksytFinanceBillAuditService.updateById(audit));
			}
		}
		return R.fail("回传文件失败");
	}




	/**
	 * @throws Exception
	 */
	@GetMapping("/downloadPdf")
	@ApiOperation(value = "下载优酷收银台PDF")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "sid", value = "序号", dataType = "Integer", required = true)
	})
	public void downloadPdf(@RequestParam String sid, HttpServletResponse response) throws Exception {
		LambdaQueryWrapper<YksytAccountView> queryWrapper = Wrappers.lambdaQuery(YksytAccountView.class).eq(YksytAccountView::getSid, sid);
		YksytAccountView yksytAccount = yksytAccountViewService.getOne(queryWrapper);
		if(yksytAccount != null) {

			// Http 1.0 header
			response.setDateHeader("Expires", 0);
			response.addHeader("Pragma", "no-cache");
			// Http 1.1 header
			response.setHeader("Cache-Control", "no-cache");
			String encodedfileName = new String(("有效用户确认单").getBytes("GBK"), "ISO8859-1");
			response.setHeader("Content-Disposition", "attachment; filename=\"" + encodedfileName + ".pdf\"");
			response.setContentType("application/vnd.ms-pdf");

			ByteArrayOutputStream baos = new ByteArrayOutputStream();
			//结算类型。1：有效用户；2：会员权益；3：出账用户；4：PRM发布
			if(yksytAccount.getDealType() == 1){
				createPdfYxyh(yksytAccount, baos);
			}
			if(yksytAccount.getDealType() == 2){
				createPdfHyqy(yksytAccount, baos);
			}
			if(yksytAccount.getDealType() == 3){
				createPdfCzyh(yksytAccount, baos);
			}
			if(yksytAccount.getDealType() == 4){
				createPdfPrm(yksytAccount, baos);
			}
			response.getOutputStream().write(baos.toByteArray());
			response.getOutputStream().flush();
		}
	}







	/**
	 * 有效用户类型PDF
	 * @param data
	 * @param baos
	 * @throws Exception
	 */
	private void createPdfYxyh(YksytAccountView data,ByteArrayOutputStream baos) throws Exception {
		Document document = new Document();
		PdfWriter.getInstance(document, baos);
		document.open();

		String theMonthStr = data.getThemonth().toString();
		String year = theMonthStr.substring(0, 4), month = theMonthStr.substring(4);

		// 使用语言包字体
		BaseFont abf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", BaseFont.NOT_EMBEDDED);
		// 外部字体
		ClassPathResource cpr = new ClassPathResource("/fonts/simfang.ttf");
		BaseFont bf = BaseFont.createFont(cpr.getPath(), BaseFont.IDENTITY_H, BaseFont.EMBEDDED);
		Font titleFont = new Font(bf, 12, Font.NORMAL);

		PdfPTable table = new PdfPTable(4);

		PdfPCell cell = new PdfPCell();
		cell.setHorizontalAlignment(Element.ALIGN_CENTER);
		cell.setVerticalAlignment(Element.ALIGN_CENTER);
		cell.setColspan(4);
		cell.setPaddingBottom(10f);
		Paragraph paragraph = new Paragraph(String.format("《%s月有效用户统计表》", month), new Font(abf, 13, Font.BOLD));
		paragraph.setAlignment(Paragraph.ALIGN_CENTER);
		cell.addElement(paragraph);
		table.addCell(cell);

		cell = new PdfPCell();
		cell.setColspan(4);
		cell.setPadding(10f);
		Paragraph para = new Paragraph(
				"1.甲方为推广其产品或服务，同意按照本协议的规定在乙方 独家代理的优酷APP收银台 渠道推广其产品或服务，按合作结算渠道推广费用。\n" +
						"2.本统计表自双方签署盖章之日起生效。\n" +
						"3.本统计表一式贰份，双方各执壹份。\n" +
						"5.请乙方收到此单据后 5个工作 日予以确认。", titleFont);
		para.setSpacingBefore(10f);
		cell.addElement(para);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("甲方：联通在线信息科技有限公司", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("乙方："  + data.getCompany(), titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("统计周期", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(String.format("%s 年 %s 月", year, month), titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("产品名称", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getSpName(), titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("新增有效用户数", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getNewuser() + "  户", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("续订有效用户数", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getOlduser() + "  户", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("结算用户数", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getTotaluser() + "  户", titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("结算费用", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		String convert = "";
		if(new BigDecimal(data.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP).compareTo(BigDecimal.ZERO) < 0){
			//负数金额
			convert = "负数"+ChineseYuanUtil.convert(new BigDecimal(data.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP).multiply(new BigDecimal(-1)).toString());
		}else {
			convert = ChineseYuanUtil.convert(new BigDecimal(data.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP).toString());
		}
		//String convert = ChineseYuanUtil.convert(new BigDecimal(data.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP).toString());
		cell = new PdfPCell(new Phrase("人民币小写："+data.getMoney() + "  元 \n" +
				"人民币大写：" + convert ,titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("乙方确认意见", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("  ", titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);



		cell = new PdfPCell(new Phrase(24,
				"甲方：联通在线信息科技有限公司 \n" +
						"\n" +
						"盖章：\n" +
						"\n" +
						"日期：",
				titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(24,
				"乙方：" + data.getCompany() +" \n" +
						"\n" +
						"盖章：\n" +
						"\n" +
						"日期：",
				titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);
		document.add(table);
		document.close();
	}



	/**
	 * 出账用户类型PDF
	 * @param data
	 * @param baos
	 * @throws Exception
	 */
	private void createPdfCzyh(YksytAccountView data, ByteArrayOutputStream baos) throws Exception {
		Document document = new Document();
		PdfWriter.getInstance(document, baos);
		document.open();

		String theMonthStr = data.getThemonth().toString();
		String year = theMonthStr.substring(0, 4), month = theMonthStr.substring(4);

		// 使用语言包字体
		BaseFont abf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", BaseFont.NOT_EMBEDDED);
		// 外部字体
		ClassPathResource cpr = new ClassPathResource("/fonts/simfang.ttf");
		BaseFont bf = BaseFont.createFont(cpr.getPath(), BaseFont.IDENTITY_H, BaseFont.EMBEDDED);
		Font titleFont = new Font(bf, 12, Font.NORMAL);

		PdfPTable table = new PdfPTable(6);

		PdfPCell cell = new PdfPCell();
		cell.setHorizontalAlignment(Element.ALIGN_CENTER);
		cell.setVerticalAlignment(Element.ALIGN_CENTER);
		cell.setColspan(6);
		cell.setPaddingBottom(10f);
		Paragraph paragraph = new Paragraph(String.format("《%s月PRM有效用户结算金额确认单》", month), new Font(abf, 13, Font.BOLD));
		paragraph.setAlignment(Paragraph.ALIGN_CENTER);
		cell.addElement(paragraph);
		table.addCell(cell);

		cell = new PdfPCell();
		cell.setColspan(6);
		cell.setPadding(10f);
		Paragraph para = new Paragraph(
				String.format("1.甲方为发展其业务，同意按照本协议的约定与乙方在 %s 开展数字媒体合作，按约定结算服务费用。\n", data.getChannelName()) +
						"2.本统计表自双方签署盖章之日起生效。\n" +
						"3.本统计表一式贰份，双方各执壹份。\n" +
						"4.请乙方收到此单据后 3 日予以确认。", titleFont);
		para.setSpacingBefore(10f);
		cell.addElement(para);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("甲方：联通在线信息科技有限公司", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("乙方：" + data.getCompany(), titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("统计周期", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(String.format("%s 年 %s 月", year, month), titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("产品名称", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getSpName(), titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("PRM新增用户数", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getNewuser() + "  户", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("PRM有效用户数", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getOlduser() + "  户", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("结算用户数", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getTotaluser() + "  户", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("结算单价", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getPrice() + " 元",titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("预估结算金额", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getMoneyReckon() + " 元",titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("总扣罚金额", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getMoneyDiscount() + " 元",titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("结算金额", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getMoney() + " 元",titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("乙方确认意见", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("  ", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase(24,
				"甲方：联通在线信息科技有限公司 \n" +
						"\n" +
						"盖章：\n" +
						"\n" +
						"日期：",
				titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(24,
				"乙方：" + data.getCompany() +" \n" +
						"\n" +
						"盖章：\n" +
						"\n" +
						"日期：",
				titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		document.add(table);
		document.close();
	}



	/**
	 * PRM发布类型PDF
	 * @param data
	 * @param baos
	 * @throws Exception
	 */
	private void createPdfPrm(YksytAccountView data,ByteArrayOutputStream baos) throws Exception {
		Document document = new Document();
		PdfWriter.getInstance(document, baos);
		document.open();

		String theMonthStr = data.getThemonth().toString();
		String year = theMonthStr.substring(0, 4), month = theMonthStr.substring(4);

		// 使用语言包字体
		BaseFont abf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", BaseFont.NOT_EMBEDDED);
		// 外部字体
		ClassPathResource cpr = new ClassPathResource("/fonts/simfang.ttf");
		BaseFont bf = BaseFont.createFont(cpr.getPath(), BaseFont.IDENTITY_H, BaseFont.EMBEDDED);
		Font titleFont = new Font(bf, 12, Font.NORMAL);

		PdfPTable table = new PdfPTable(4);

		PdfPCell cell = new PdfPCell();
		cell.setHorizontalAlignment(Element.ALIGN_CENTER);
		cell.setVerticalAlignment(Element.ALIGN_CENTER);
		cell.setColspan(4);
		cell.setPaddingBottom(10f);
		Paragraph paragraph = new Paragraph(String.format("中国联通畅视互娱业务推广合作结算单", month), new Font(abf, 13, Font.BOLD));
		paragraph.setAlignment(Paragraph.ALIGN_CENTER);
		cell.addElement(paragraph);
		table.addCell(cell);

		cell = new PdfPCell();
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("渠道名称：" + data.getChannelName(), titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("结算月份（示例2002年9月）", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(String.format("%s 年 %s 月", year, month), titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("结算金额（单位：元人民币 ）", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		String convert = "";
		if(new BigDecimal(data.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP).compareTo(BigDecimal.ZERO) < 0){
			//负数金额
			convert = "负数"+ChineseYuanUtil.convert(new BigDecimal(data.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP).multiply(new BigDecimal(-1)).toString());
		}else {
			convert = ChineseYuanUtil.convert(new BigDecimal(data.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP).toString());
		}
		//String convert = ChineseYuanUtil.convert(new BigDecimal(data.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP).toString());
		cell = new PdfPCell(new Phrase(data.getMoney() + " 元" ,titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("业务名称：", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getSpName(), titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("业务负责人：", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("联系电话：", titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("财务章：\n\n\n"+
				"\n\n\n\n", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("签字日期：", titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("收款人名称（全称）：", titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("收款银行（全称）：", titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("银行账号：", titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		table.addCell(cell);
		document.add(table);
		document.close();
	}


	/**
	 * 会员权益类型PDF
	 * @param data
	 * @param baos
	 * @throws Exception
	 */
	private void createPdfHyqy(YksytAccountView data, ByteArrayOutputStream baos) throws Exception {
		List<FinVippoolMonthDetail> list = null;
		if(StringUtils.isNotBlank(data.getChannelName())){
			list = finVippoolMonthDetailService.list(new LambdaQueryWrapper<FinVippoolMonthDetail>()
					.eq(FinVippoolMonthDetail::getChannelid,data.getChannelId())
					.eq(FinVippoolMonthDetail::getThemonth,data.getThemonth())
			);
		}
		Document document = new Document();
		PdfWriter.getInstance(document, baos);
		document.open();

		String theMonthStr = data.getThemonth().toString();
		String year = theMonthStr.substring(0, 4), month = theMonthStr.substring(4);

		// 使用语言包字体
		BaseFont abf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", BaseFont.NOT_EMBEDDED);
		// 外部字体
		ClassPathResource cpr = new ClassPathResource("/fonts/simfang.ttf");
		BaseFont bf = BaseFont.createFont(cpr.getPath(), BaseFont.IDENTITY_H, BaseFont.EMBEDDED);
		Font titleFont = new Font(bf, 12, Font.NORMAL);

		PdfPTable table = new PdfPTable(8);

		PdfPCell cell = new PdfPCell();
		cell.setHorizontalAlignment(Element.ALIGN_CENTER);
		cell.setVerticalAlignment(Element.ALIGN_CENTER);
		cell.setColspan(8);
		cell.setPaddingBottom(10f);
		Paragraph paragraph = new Paragraph(String.format("付款通知书", month), new Font(abf, 13, Font.BOLD));
		paragraph.setAlignment(Paragraph.ALIGN_CENTER);
		cell.addElement(paragraph);
		table.addCell(cell);

		cell = new PdfPCell();
		cell.setColspan(8);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("致：联通在线信息科技有限公司：" , titleFont));
		cell.setColspan(8);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("我公司与贵公司签订了", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(String.format("视频会员业务合作协议-%s", data.getCompany()), titleFont));
		cell.setColspan(5);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("结算明细", titleFont));
		cell.setColspan(8);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("权益名称", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("数量", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("单价：元/个", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("总计金额：元", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);

		BigDecimal totalMoney = BigDecimal.ZERO;
		if(list != null && list.size() > 0){
			for (FinVippoolMonthDetail detail : list) {
				totalMoney = totalMoney.add(detail.getMoney()).setScale(2,BigDecimal.ROUND_HALF_UP);
				cell = new PdfPCell(new Phrase(detail.getQyName(), titleFont));
				cell.setColspan(2);
				cell.setPadding(10f);
				table.addCell(cell);
				cell = new PdfPCell(new Phrase(detail.getNum().toString(), titleFont));
				cell.setColspan(2);
				cell.setPadding(10f);
				table.addCell(cell);
				cell = new PdfPCell(new Phrase(detail.getCostprice() + "", titleFont));
				cell.setColspan(2);
				cell.setPadding(10f);
				table.addCell(cell);
				cell = new PdfPCell(new Phrase(detail.getMoney() + "" ,titleFont));
				cell.setColspan(2);
				cell.setPadding(10f);
				table.addCell(cell);
			}
		}

		cell = new PdfPCell(new Phrase("账期", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(String.format("%s 年 %s 月", year, month), titleFont));
		cell.setColspan(5);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("本次申请付款金额：", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(totalMoney + " 元", titleFont));
		cell.setColspan(5);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("收款单位信息 \n\n\n\n", titleFont));
		cell.setColspan(3);
		cell.setRowspan(3);
		cell.setPadding(10f);
		table.addCell(cell);


		String bankName = "";
		String bankCode = "";

		PartnerInformationEnum[] values = PartnerInformationEnum.values();
		for (PartnerInformationEnum value : values) {
			if(value.getPartnerName().equals(data.getCompany())){
				bankName = value.getBankName();
				bankCode = value.getBankCode();
			}
		}

		cell = new PdfPCell(new Phrase("收款单位名称", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getCompany(), titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("开户银行：", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(bankName, titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("银行账号：", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(bankCode, titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("供应商联系人", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("         ", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("供应商联系电话", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("        ", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("其他情况说明：", titleFont));
		cell.setColspan(3);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("        ", titleFont));
		cell.setColspan(5);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase(24,
				"供应商单位盖章 ： \n" +
						"\n" +"\n" +"\n" +
						"年"+"\t"+"\t"+"\t"+"\t"+"月"+"\t"+"\t"+"\t"+"\t"+"日；",
				titleFont));
		cell.setColspan(8);
		cell.setPaddingRight(20f);
		//cell.setPadding(10f);
		table.addCell(cell);
		document.add(table);
		document.close();
	}


}

