/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package com.platomix.intchannel.model;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 内部结算-结算产品表实体类
 *
 * @author zbc
 * @since 2022-07-20
 */
@Data
@TableName("INNER_COMAPNY_SPID")
public class InnerComapnySpid implements Serializable {

	private static final long serialVersionUID = 1L;

	@ApiModelProperty(value = "结算单类型")
	private String dealType;

	@ApiModelProperty(value = "结算方名称")
	private String company;

	@ApiModelProperty(value = "产品ID")
	private String spid;

	@ApiModelProperty(value = "产品名称")
	private String spname;

	@ApiModelProperty(value = "PRM业务名称")
	private String spnamePrm;

	@ApiModelProperty(value = "产品价格")
	private BigDecimal price;

	@ApiModelProperty(value = "结算单价")
	private BigDecimal dealPrice;

	@ApiModelProperty(value = "合作开始月份")
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date accountStartdate;

	@ApiModelProperty(value = "合作结束月份")
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date accountEnddate;

	@ApiModelProperty(value = "是否有效。1：有效；0：无效；")
	private Integer isValid;

	@ApiModelProperty(value = "数据生成开始月份")
	private Date dataStartdate;

	@ApiModelProperty(value = "录入人")
	private String inputter;

	@ApiModelProperty(value = "录入时间")
	@JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
	private Date inputTime;

	@ApiModelProperty(value = "审核人")
	private String checker;

	@ApiModelProperty(value = "审核时间")
	private Date checkTime;

	@ApiModelProperty(value = "状态。0：待审核；1：审核通过；2：审核不通过；")
	private Integer status;

	@ApiModelProperty(value = " 结算单ID。一个结算用户可以对应多个结算单，一个结算单可以对应1-N个结算渠道。")
	private String dealAccountId;


	@ApiModelProperty(value = "录入人名称")
	@TableField(exist = false)
	private String inputName;

	@ApiModelProperty(value = "审核人名称")
	@TableField(exist = false)
	private String checkName;

}
