/**
 * 
 */
package com.platomix.intchannel.utils;

import java.security.NoSuchAlgorithmException;
import java.util.Base64;

import javax.crypto.Cipher;
import javax.crypto.KeyGenerator;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * @author wookvn
 *
 */
public class AESUtils {

	final static Logger LOGGER = LoggerFactory.getLogger(AESUtils.class);
	
	/**
	 * 生成AES密钥，生成的密钥用BASE64编码
	 * 128位(256位可能不支持)
	 * @see <a href="http://www.javamex.com/tutorials/cryptography/key_size.shtml">key size</a>
	 * 
	 * @return
	 * @throws Exception
	 */
	private static String getKey() {
		try {
			KeyGenerator kgen = KeyGenerator.getInstance("AES");
			kgen.init(128); // 192 and 256 bits may not be available
			SecretKey skey = kgen.generateKey();
			byte[] raw = skey.getEncoded();
			return Base64.getEncoder().encodeToString(raw);
		} catch (NoSuchAlgorithmException e) {
			LOGGER.error(e.getMessage(), e);
		}
		return null;
	}

	/**
	 * AES加密，加密成Base64字节流
	 * 
	 * @param content 需要加密的字符串
	 * @param key BASE64编码密钥
	 * @return
	 * @throws Exception
	 */
	public static String encode(String content, String key) {
		try {
			byte[] raw = Base64.getDecoder().decode(key);
			SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
			Cipher cipher = Cipher.getInstance("AES");
			cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
			byte[] encrypted = cipher.doFinal(content.getBytes("UTF-8"));
			return Base64.getEncoder().encodeToString(encrypted).replaceAll("\\+", "~").replaceAll("/", "*");
		} catch (Exception e) {
			LOGGER.error("AES Encode Failed!!content=" + content, e);
			return null;
		}
	}

	/**
	 * AES解密，解密成字符串
	 * 
	 * @param stream 需要解密的字节流
	 * @param key BASE64编码密钥
	 * @return
	 * @throws Exception
	 */
	public static String decode(String signSource, String key) {
		String originalString;
		try {
			signSource = signSource.replaceAll("~", "+").replaceAll("\\*", "/");
			byte[] raw = Base64.getDecoder().decode(key);
			SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
			Cipher cipher = Cipher.getInstance("AES");
			cipher.init(Cipher.DECRYPT_MODE, skeySpec);
			byte[] original = cipher.doFinal(Base64.getDecoder().decode(signSource));
			originalString = new String(original, "UTF-8");
		} catch (Exception e) {
			LOGGER.error("AES Decode Failed!!source=" + signSource, e);
			return null;
		}
		return originalString;
	}
	
	public static void main(String[] args) {
		String key = getKey();
		System.out.println(key);
		String value = String.format("%07d", 1);
		System.out.println(AESUtils.encode(value, key));
	}
}
